Class: Tebako::Cli
- Inherits:
-
Thor
- Object
- Thor
- Tebako::Cli
- Defined in:
- lib/tebako/cli.rb
Overview
Tebako packager front-end
Constant Summary collapse
- CWD_DESCRIPTION =
<<~DESC Current working directory for packaged application. This directory shall be specified relative to root. #{" " * 65}# If this parameter is not set, the application will start in the current directory of the host file system. DESC
- REF_DESCRIPTION =
<<~DESC "Referenced tebako run-time package; 'tebako-runtime' by default". #{" " * 65}# This option specifies the tebako runtime to be used by the application on Windows and if mode is 'application' only . DESC
- RGP_DESCRIPTION =
<<~DESC Current working directory for packaged application. This directory shall be specified relative to root. #{" " * 65}# If this parameter is not set, the application will start in the current directory of the host file system. DESC
Class Method Summary collapse
Instance Method Summary collapse
Class Method Details
.exit_on_failure? ⇒ Boolean
142 143 144 |
# File 'lib/tebako/cli.rb', line 142 def self.exit_on_failure? true end |
Instance Method Details
#clean ⇒ Object
58 59 60 61 62 |
# File 'lib/tebako/cli.rb', line 58 def clean (om, cm) = bootstrap(clean: true) cm.clean_cache extra_win_clean([om.deps]) end |
#clean_ruby ⇒ Object
68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/tebako/cli.rb', line 68 def clean_ruby puts "Cleaning Ruby sources from tebako packaging environment" (om,) = bootstrap(clean: true) suffix = ["Ruby"].nil? ? "" : "_#{["Ruby"]}" nmr = Dir.glob(File.join(om.deps, "src", "_ruby#{suffix}*")) nms = Dir.glob(File.join(om.deps, "stash#{suffix}*")) FileUtils.rm_rf(nmr + nms, secure: true) extra_win_clean(nmr) end |
#hash ⇒ Object
81 82 83 |
# File 'lib/tebako/cli.rb', line 81 def hash print Digest::SHA256.hexdigest [File.read(File.join(source, "CMakeLists.txt")), Tebako::VERSION].join end |